@@ -33,11 +33,15 @@ class DebImporter(Pulp2to3Importer):
         """
         pulp2_config = pulp2importer.pulp2_config
         base_config, name = cls.parse_base_config(pulp2importer, pulp2_config)
-        base_config['name'] = name
-        base_config['distributions'] = pulp2_config.get('releases').replace(',', ' ')
-        base_config['components'] = pulp2_config.get('components').replace(',', ' ')
-        base_config['architectures'] = pulp2_config.get('architectures').replace(',', ' ')
-        return AptRemote.objects.update_or_create(**base_config)
+        base_config['distributions'] = pulp2_config.get('releases', 'stable').replace(',', ' ')
+        components = pulp2_config.get('components')
+        if components:
+            base_config['components'] = components.replace(',', ' ')
+        architectures = pulp2_config.get('architectures')
+        if architectures:
+            base_config['architectures'] = architectures.replace(',', ' ')
+        base_config['gpgkey'] = pulp2_config.get('gpg_keys')
+        return AptRemote.objects.update_or_create(name=name, defaults=base_config)
 
 
 class DebDistributor(Pulp2to3Distributor):
@@ -65,17 +69,17 @@ class DebDistributor(Pulp2to3Distributor):
         if not repo_version:
             repo = pulp2distributor.pulp2_repos.filter(not_in_plan=False, is_migrated=True)
             repo_version = repo[0].pulp3_repository_version
-        publication = repo_version.publication_set.first()
+        publication = repo_version.publication_set.filter(complete=True).first()
         if not publication:
             # create publication
             publish(repo_version.pk, simple=True, structured=True)
-            publication = repo_version.publication_set.first()
+            publication = repo_version.publication_set.filter(complete=True).first()
 
         # create distribution
         pulp2_config = pulp2distributor.pulp2_config
         distribution_data = cls.parse_base_config(pulp2distributor, pulp2_config)
         base_path = pulp2_config.get('relative_url', pulp2distributor.pulp2_repo_id)
-        distribution_data['base_path'] = base_path.rstrip('/')
+        distribution_data['base_path'] = base_path.strip('/')
         distribution_data['publication'] = publication
         distribution, created = AptDistribution.objects.update_or_create(
             name=distribution_data['name'],
